@@ -1536,3 +1536,23 @@ class MultirotorClient(VehicleClient, object):
         """ Disables race log """
         self.client.call('simDisableRaceLog')
 
+    def simIsRacerDisqualified(self, vehicle_name):
+        """
+        Args:
+            vehicle_name (str): Name of the multirotor to send this command to 
+        
+        Returns:
+            bool: True if vehicle_name is disqualified. False if not
+        """
+        return self.client.call('simGetDisqualified', vehicle_name)
+
+    def simGetLastGatePassed(self, vehicle_name):
+        """
+        
+        Args:
+            vehicle_name (str): Name of the multirotor to send this command to 
+        
+        Returns:
+            int: index of last gate passed by vehicle_name
+        """
+        return self.client.call('simGetLastGatePassed', vehicle_name)
